summaryrefslogtreecommitdiff
path: root/var
diff options
context:
space:
mode:
authorMichael Kuhn <michael.kuhn@ovgu.de>2023-03-09 01:02:38 +0100
committerGitHub <noreply@github.com>2023-03-08 19:02:38 -0500
commitcc4f7c224a0ec6ec552389578b114f49a14cf5c5 (patch)
tree6c722496ea4be62058ef774dbc02a444d852edca /var
parentee5b2936e4783c9e8d7ce353452ed06953bbd612 (diff)
downloadspack-cc4f7c224a0ec6ec552389578b114f49a14cf5c5.tar.gz
spack-cc4f7c224a0ec6ec552389578b114f49a14cf5c5.tar.bz2
spack-cc4f7c224a0ec6ec552389578b114f49a14cf5c5.tar.xz
spack-cc4f7c224a0ec6ec552389578b114f49a14cf5c5.zip
libuv-julia: fix mtime again (#35945)
On some systems touch runs out of order, so set a equal mtimes to the relevant files
Diffstat (limited to 'var')
-rw-r--r--var/spack/repos/builtin/packages/libuv-julia/package.py17
1 files changed, 12 insertions, 5 deletions
diff --git a/var/spack/repos/builtin/packages/libuv-julia/package.py b/var/spack/repos/builtin/packages/libuv-julia/package.py
index f9e2c75af8..ee53bbb26a 100644
--- a/var/spack/repos/builtin/packages/libuv-julia/package.py
+++ b/var/spack/repos/builtin/packages/libuv-julia/package.py
@@ -2,6 +2,9 @@
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)
+import os
+import time
+
from spack.package import *
@@ -19,11 +22,15 @@ class LibuvJulia(AutotoolsPackage):
version("1.42.0", commit="3a63bf71de62c64097989254e4f03212e3bf5fc8")
def autoreconf(self, spec, prefix):
- # @haampie: Configure files are checked in, but git does not restore mtime
- # by design. Therefore, touch files to avoid regenerating those.
- touch("aclocal.m4")
- touch("Makefile.in")
- touch("configure")
+ # @haampie: Configure files are checked in, but git does not restore
+ # mtime by design. Therefore, touch files to avoid regenerating those.
+ # Make sure to set them all to the same time, otherwise weird problems
+ # might occur (https://github.com/spack/spack/pull/35945).
+ cur = time.time()
+ times = (cur, cur)
+ os.utime("aclocal.m4", times)
+ os.utime("Makefile.in", times)
+ os.utime("configure", times)
@property
def libs(self):